ShadHoverStrategies class

Annotations

Constructors

ShadHoverStrategies({Set<ShadHoverStrategy> hover = const {}, Set<ShadHoverStrategy> unhover = const {}, Duration? longPressDuration, ValueChanged<bool>? onHoverChange})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
hover Set<ShadHoverStrategy>
final
longPressDuration Duration?
final
onHoverChange ValueChanged<bool>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unhover Set<ShadHoverStrategy>
final

Methods

copyWith({Set<ShadHoverStrategy>? hover, Set<ShadHoverStrategy>? unhover, Duration? longPressDuration, ValueChanged<bool>? onHoverChange}) ShadHoverStrategies
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override