ShadPanelInfo class

The size information of a panel

Constructors

ShadPanelInfo({required Object id, required double defaultSize, double minSize = 0, double maxSize = 0})

Properties

defaultSize double
The default size of the panel, which is set during initialization. Must be between minSize and maxSize.
final
hashCode int
The hash code for this object.
no setterinherited
id Object
The unique identifier for the panel. This must be unique among all panels in the group.
final
maxSize double
The maximum size the panel can be resized to. Must be between 0 and 1.
final
minSize double
The minimum size the panel can be resized to. Must be between 0 and 1.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited