ShadPositionDelegate class

A delegate for computing the layout of an overlay to be displayed above or below a target specified in the global coordinate system.

Inheritance

Constructors

ShadPositionDelegate({required Offset target, required double verticalOffset, required bool preferBelow})
Creates a delegate for computing the layout of an overlay.

Properties

hashCode int
The hash code for this object.
no setterinherited
preferBelow bool
Whether the overlay is displayed below its widget by default.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target Offset
The offset of the target the overlay is positioned near in the global coordinate system.
final
verticalOffset double
The amount of vertical distance between the target and the displayed overlay.
final

Methods

getConstraintsForChild(BoxConstraints constraints) BoxConstraints
The constraints for the child given the incoming constraints.
override
getPositionForChild(Size size, Size childSize) Offset
The position where the child should be placed.
override
getSize(BoxConstraints constraints) Size
The size of this object given the incoming constraints.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRelayout(covariant ShadPositionDelegate oldDelegate) bool
Called whenever a new instance of the custom layout delegate class is provided to the RenderCustomSingleChildLayoutBox object, or any time that a new CustomSingleChildLayout object is created with a new instance of the custom layout delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited